@@ -1,15 +1,15 @@
 import pickle  # nosec
 from typing import Any, Dict
-
+import joblib
 from ..object_manager import ModelManager
-from ..utils import to_file, from_file
+from ..utils import from_file
 
 
 class SKLearnModelManager(ModelManager):
     framework = "sklearn"
 
     def save_object(self, obj: Any):
-        to_file(pickle.dumps(obj), self.object_file_path, "wb+")
+        joblib.dump(obj, self.object_file_path)
 
     def load_object(self) -> Any:
         """
@@ -17,7 +17,11 @@ class SKLearnModelManager(ModelManager):
         may be inconsistencies where different versions of SKLearn are used for pickling and unpickling.
         :return:
         """
-        return pickle.loads(from_file(self.object_file_path, "rb"))  # nosec
+        try:
+            return joblib.load(self.object_file_path)
+        except Exception:
+            # fallback on pickle for old filesz
+            return pickle.loads(from_file(self.object_file_path, "rb"))  # nosec
 
     def hash_object(self, obj) -> int:
         return hash(str(obj))
